from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Transformer = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'0896BM15A0001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'0896BM15A0001'}), 'ref_prefix':'U', 'fplist':['RF_Converter:Balun_Johanson_0896BM15A0001'], 'footprint':'RF_Converter:Balun_Johanson_0896BM15A0001', 'keywords':'balun rf transformer', 'description':'', 'datasheet':'https://www.johansontechnology.com/datasheets/0896BM15A0001/0896BM15A0001.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n0896BM15A0001\n\nbalun rf transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'30F-51NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'30F-51NL'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_YDS_30F-51NL_SO-24_7.1x15.1mm'], 'footprint':'Transformer_SMD:Transformer_Ethernet_YDS_30F-51NL_SO-24_7.1x15.1mm', 'keywords':'gigabit RJ45 transformer ethernet lan', 'description':'', 'datasheet':'https://datasheet.lcsc.com/lcsc/1811051610_Shanghai-YDS-Tech-30F-51NL_C123168.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n30F-51NL\n\ngigabit RJ45 transformer ethernet lan', 'pins':[
            Pin(num='1',name='CT',func=pin_types.PASSIVE),
            Pin(num='10',name='CT',func=pin_types.PASSIVE),
            Pin(num='11',name='TD4+',func=pin_types.PASSIVE),
            Pin(num='12',name='TD4-',func=pin_types.PASSIVE),
            Pin(num='13',name='MX4-',func=pin_types.PASSIVE),
            Pin(num='14',name='MX4+',func=pin_types.PASSIVE),
            Pin(num='15',name='CT',func=pin_types.PASSIVE),
            Pin(num='16',name='MX3-',func=pin_types.PASSIVE),
            Pin(num='17',name='MX3+',func=pin_types.PASSIVE),
            Pin(num='18',name='CT',func=pin_types.PASSIVE),
            Pin(num='19',name='MX2-',func=pin_types.PASSIVE),
            Pin(num='2',name='TD1+',func=pin_types.PASSIVE),
            Pin(num='20',name='MX2+',func=pin_types.PASSIVE),
            Pin(num='21',name='CT',func=pin_types.PASSIVE),
            Pin(num='22',name='MX1-',func=pin_types.PASSIVE),
            Pin(num='23',name='MX1+',func=pin_types.PASSIVE),
            Pin(num='24',name='CT',func=pin_types.PASSIVE),
            Pin(num='3',name='TD1-',func=pin_types.PASSIVE),
            Pin(num='4',name='CT',func=pin_types.PASSIVE),
            Pin(num='5',name='TD2+',func=pin_types.PASSIVE),
            Pin(num='6',name='TD2-',func=pin_types.PASSIVE),
            Pin(num='7',name='CT',func=pin_types.PASSIVE),
            Pin(num='8',name='TD3+',func=pin_types.PASSIVE),
            Pin(num='9',name='TD3-',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'5400BL15B050', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'5400BL15B050'}), 'ref_prefix':'U', 'fplist':['RF_Converter:Balun_Johanson_5400BL15B050E'], 'footprint':'RF_Converter:Balun_Johanson_5400BL15B050E', 'keywords':'balun rf transformer', 'description':'', 'datasheet':'https://www.johansontechnology.com/datasheets/5400BL15B050/5400BL15B050.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n5400BL15B050\n\nbalun rf transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1-1WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1-1WT'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1-1WT.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1-1WT\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1-1WT-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1-1WT-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1-1WT-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1-1WT-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1-6T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1-6T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1-6T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1-6T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1.5-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1.5-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1.5-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1.5-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1.5-122', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1.5-122'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1.5-122+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1.5-122\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1.5-17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1.5-17'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1.5-17+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1.5-17\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT1.5-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT1.5-2'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT1.5-2+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT1.5-2\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT2-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT2-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT2-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT2-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT3-6T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT3-6T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT3-6T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT3-6T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-6'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-6+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-6\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTL1-15-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTL1-15-75'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTL1-15-75+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTL1-15-75\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTL1-4-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTL1-4-75'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTL1-4-75+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTL1-4-75\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTT1-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTT1-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTT1-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTT1-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTT1-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTT1-6'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTT1-6+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTT1-6\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTT1.5-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTT1.5-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTT1.5-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTT1.5-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CST1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST1'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST1'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST1', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST1\n\ncurrent sense transformer', 'pins':[
            Pin(num='4',name='4',func=pin_types.PASSIVE),
            Pin(num='6',name='6',func=pin_types.PASSIVE),
            Pin(num='7',name='7',func=pin_types.PASSIVE),
            Pin(num='8',name='8',func=pin_types.PASSIVE),
            Pin(num='1',name='1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='3',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CST1_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST1_Split'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST1'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST1', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST1_Split\n\ncurrent sense transformer', 'pins':[
            Pin(num='1',name='1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=2),
            Pin(num='3',name='3',func=pin_types.NOCONNECT,unit=2),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=2),
            Pin(num='6',name='6',func=pin_types.PASSIVE,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '5', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '6', '3', '2']}] }),
        Part(**{ 'name':'CST2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST2'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST2'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST2', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST2\n\ncurrent sense transformer', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE),
            Pin(num='3',name='3',func=pin_types.PASSIVE),
            Pin(num='7',name='7',func=pin_types.PASSIVE),
            Pin(num='8',name='8',func=pin_types.PASSIVE),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='4',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='6',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CST2010', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST2010'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST2010'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST2010', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst2010.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST2010\n\ncurrent sense transformer', 'pins':[
            Pin(num='11',name='11',func=pin_types.PASSIVE),
            Pin(num='12',name='12',func=pin_types.PASSIVE),
            Pin(num='2',name='2',func=pin_types.PASSIVE),
            Pin(num='4',name='4',func=pin_types.PASSIVE),
            Pin(num='1',name='1',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='10',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='3',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='6',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='7',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='8',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='9',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CST2010_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST2010_Split'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST2010'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST2010', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst2010.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST2010_Split\n\ncurrent sense transformer', 'pins':[
            Pin(num='10',name='10',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='11',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='12',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.NOCONNECT,unit=2),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='3',func=pin_types.NOCONNECT,unit=2),
            Pin(num='4',name='4',func=pin_types.PASSIVE,unit=2),
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=2),
            Pin(num='6',name='6',func=pin_types.NOCONNECT,unit=2),
            Pin(num='7',name='7',func=pin_types.NOCONNECT,unit=2),
            Pin(num='8',name='8',func=pin_types.NOCONNECT,unit=2),
            Pin(num='9',name='9',func=pin_types.NOCONNECT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['10', '11', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '4', '7', '9', '3', '8', '2', '6', '5']}] }),
        Part(**{ 'name':'CST2_Split', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CST2_Split'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_Coilcraft_CST2'], 'footprint':'Transformer_SMD:Transformer_Coilcraft_CST2', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://www.coilcraft.com/pdfs/cst.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nCST2_Split\n\ncurrent sense transformer', 'pins':[
            Pin(num='5',name='5',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='6',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='7',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='8',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=2),
            Pin(num='2',name='2',func=pin_types.NOCONNECT,unit=2),
            Pin(num='3',name='3',func=pin_types.PASSIVE,unit=2),
            Pin(num='4',name='4',func=pin_types.NOCONNECT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '7', '6', '8']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '1', '2', '3']}] }),
        Part(**{ 'name':'ED8_4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ED8_4'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Transformer_ED8_4-Lead_10.5x8mm_P5mm'], 'footprint':'Transformer_SMD:Transformer_ED8_4-Lead_10.5x8mm_P5mm', 'keywords':'ED8 4-lead body 10.5x8mm body pitch 5mm height 5mm', 'description':'', 'datasheet':'https://gitlab.com/kicad/libraries/kicad-footprints/-/merge_requests/3626', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nED8_4\n\nED8 4-lead body 10.5x8mm body pitch 5mm height 5mm', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ETC1-1-13', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ETC1-1-13'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_MACOM_SM-22'], 'footprint':'Transformer_SMD:Transformer_MACOM_SM-22', 'keywords':'MACOM RF Transformer', 'description':'', 'datasheet':'https://cdn.macom.com/datasheets/ETC1-1-13.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nETC1-1-13\n\nMACOM RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='MP',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LL1587', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LL1587'}), 'ref_prefix':'T', 'fplist':['Transformer_THT:Transformer_Microphone_Lundahl_LL1587'], 'footprint':'Transformer_THT:Transformer_Microphone_Lundahl_LL1587', 'keywords':'microphone transformer', 'description':'', 'datasheet':'http://www.lundahl.se/wp-content/uploads/datasheets/1587.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nLL1587\n\nmicrophone transformer', 'pins':[
            Pin(num='1',name='P1+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='P1-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='P2-',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='P2+',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='S-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='S+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'P0926NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P0926NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_P0926NL'], 'footprint':'Transformer_SMD:Pulse_P0926NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nP0926NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA1323NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA1323NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA1323NL'], 'footprint':'Transformer_SMD:Pulse_PA1323NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA1323NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2001NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2001NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2001NL'], 'footprint':'Transformer_SMD:Pulse_PA2001NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2001NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2002NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2002NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2002NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2004NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2004NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2004NL'], 'footprint':'Transformer_SMD:Pulse_PA2004NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2004NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2005NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2005NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2005NL'], 'footprint':'Transformer_SMD:Pulse_PA2005NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2005NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2006NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2006NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2006NL'], 'footprint':'Transformer_SMD:Pulse_PA2006NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2006NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2007NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2007NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2007NL'], 'footprint':'Transformer_SMD:Pulse_PA2007NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2007NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2777NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2777NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2777NL'], 'footprint':'Transformer_SMD:Pulse_PA2777NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2777NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA3493NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA3493NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA3493NL'], 'footprint':'Transformer_SMD:Pulse_PA3493NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA3493NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PT61017PEL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PT61017PEL'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_Bourns_PT61017PEL'], 'footprint':'Transformer_SMD:Transformer_Ethernet_Bourns_PT61017PEL', 'keywords':'single port ethernet transformer poe center-tap', 'description':'', 'datasheet':'https://www.bourns.com/docs/Product-Datasheets/PT61017PEL.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPT61017PEL\n\nsingle port ethernet transformer poe center-tap', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='C_RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C_TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C_TD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C_RD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='RX-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PT61020EL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PT61020EL'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_Bourns_PT61020EL'], 'footprint':'Transformer_SMD:Transformer_Ethernet_Bourns_PT61020EL', 'keywords':'Gigabit PoE RJ45 Transformer Ethernet Lan', 'description':'', 'datasheet':'https://www.bourns.com/pdfs/PT61020.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPT61020EL\n\nGigabit PoE RJ45 Transformer Ethernet Lan', 'pins':[
            Pin(num='1',name='TCT1',func=pin_types.PASSIVE),
            Pin(num='10',name='TCT4',func=pin_types.PASSIVE),
            Pin(num='11',name='TD4+',func=pin_types.PASSIVE),
            Pin(num='12',name='TD4-',func=pin_types.PASSIVE),
            Pin(num='13',name='MX4-',func=pin_types.PASSIVE),
            Pin(num='14',name='MX4+',func=pin_types.PASSIVE),
            Pin(num='15',name='MCT4',func=pin_types.PASSIVE),
            Pin(num='16',name='MX3-',func=pin_types.PASSIVE),
            Pin(num='17',name='MX3+',func=pin_types.PASSIVE),
            Pin(num='18',name='MCT3',func=pin_types.PASSIVE),
            Pin(num='19',name='MX2-',func=pin_types.PASSIVE),
            Pin(num='2',name='TD1+',func=pin_types.PASSIVE),
            Pin(num='20',name='MX2+',func=pin_types.PASSIVE),
            Pin(num='21',name='MCT2',func=pin_types.PASSIVE),
            Pin(num='22',name='MX1-',func=pin_types.PASSIVE),
            Pin(num='23',name='MX1+',func=pin_types.PASSIVE),
            Pin(num='24',name='MCT1',func=pin_types.PASSIVE),
            Pin(num='3',name='TD1-',func=pin_types.PASSIVE),
            Pin(num='4',name='TCT2',func=pin_types.PASSIVE),
            Pin(num='5',name='TD2+',func=pin_types.PASSIVE),
            Pin(num='6',name='TD2-',func=pin_types.PASSIVE),
            Pin(num='7',name='TCT3',func=pin_types.PASSIVE),
            Pin(num='8',name='TD3+',func=pin_types.PASSIVE),
            Pin(num='9',name='TD3-',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'TC1-1-13M+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC1-1-13M+'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_MiniCircuits_AT224-1A'], 'footprint':'Transformer_SMD:Transformer_MiniCircuits_AT224-1A', 'keywords':'Mini-circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/TC1-1-13M+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTC1-1-13M+\n\nMini-circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ0.5-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ0.5-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-22x24'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-22x24', 'keywords':'0.5VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ0.5-D-1\n\n0.5VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ0.5-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ0.5-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-22x24'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-22x24', 'keywords':'0.5VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ0.5-D-2\n\n0.5VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ1.5-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ1.5-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'1.5VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ1.5-D-1\n\n1.5VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ1.5-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ1.5-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'1.5VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ1.5-D-2\n\n1.5VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ10.0-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ10.0-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-44x52'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-44x52', 'keywords':'10VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ10.0-D-1\n\n10VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ10.0-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ10.0-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-44x52'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-44x52', 'keywords':'10VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ10.0-D-2\n\n10VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ16.0-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ16.0-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-47x57'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-47x57', 'keywords':'16VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ16.0-D-1\n\n16VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ16.0-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ16.0-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-47x57'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-47x57', 'keywords':'16VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ16.0-D-2\n\n16VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.0-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.0-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.0-D-1\n\n2VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.0-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.0-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.0-D-2\n\n2VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.5-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.5-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2.5VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.5-D-1\n\n2.5VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.5-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.5-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2.5VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.5-D-2\n\n2.5VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.6-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.6-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2.6VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.6-D-1\n\n2.6VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ2.6-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ2.6-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-28x33'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-28x33', 'keywords':'2.6VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ2.6-D-2\n\n2.6VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ4.0-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ4.0-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-35x42'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-35x42', 'keywords':'4VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ4.0-D-1\n\n4VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ4.0-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ4.0-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-35x42'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-35x42', 'keywords':'4VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ4.0-D-2\n\n4VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ6.0-D-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ6.0-D-1'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-38x45'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-38x45', 'keywords':'6VA PCB Transformer Single Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ6.0-D-1\n\n6VA PCB Transformer Single Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TEZ6.0-D-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TEZ6.0-D-2'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Breve_TEZ-38x45'], 'footprint':'Transformer_THT:Transformer_Breve_TEZ-38x45', 'keywords':'6VA PCB Transformer Dual Secondary', 'description':'', 'datasheet':'http://www.breve.pl/pdf/ANG/TEZ_ang.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTEZ6.0-D-2\n\n6VA PCB Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TG110-E050N5xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TG110-E050N5xx'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_Halo_N5_SO-16_7.11x12.7mm'], 'footprint':'Transformer_SMD:Transformer_Ethernet_Halo_N5_SO-16_7.11x12.7mm', 'keywords':'single port ethernet transformer', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/discrete-ultra-100baset.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTG110-E050N5xx\n\nsingle port ethernet transformer', 'pins':[
            Pin(num='1',name='TX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='C_RD',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C_TD',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C_TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='RX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C_RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='RD+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TG111-MSC13LF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TG111-MSC13LF'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_HALO_TG111-MSC13'], 'footprint':'Transformer_SMD:Transformer_Ethernet_HALO_TG111-MSC13', 'keywords':'Single Port Gigabit Ethernet Transformer', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/discrete-genesus.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTG111-MSC13LF\n\nSingle Port Gigabit Ethernet Transformer', 'pins':[
            Pin(num='1',name='TCT1',func=pin_types.PASSIVE),
            Pin(num='10',name='TCT4',func=pin_types.PASSIVE),
            Pin(num='11',name='TD4+',func=pin_types.PASSIVE),
            Pin(num='12',name='TD4-',func=pin_types.PASSIVE),
            Pin(num='13',name='MX4-',func=pin_types.PASSIVE),
            Pin(num='14',name='MX4+',func=pin_types.PASSIVE),
            Pin(num='15',name='MCT4',func=pin_types.PASSIVE),
            Pin(num='16',name='MTX3-',func=pin_types.PASSIVE),
            Pin(num='17',name='MTX3+',func=pin_types.PASSIVE),
            Pin(num='18',name='MCT3',func=pin_types.PASSIVE),
            Pin(num='19',name='MTX2-',func=pin_types.PASSIVE),
            Pin(num='2',name='TD1+',func=pin_types.PASSIVE),
            Pin(num='20',name='MTX2+',func=pin_types.PASSIVE),
            Pin(num='21',name='MCT2',func=pin_types.PASSIVE),
            Pin(num='22',name='MTX1-',func=pin_types.PASSIVE),
            Pin(num='23',name='MTX1+',func=pin_types.PASSIVE),
            Pin(num='24',name='MTC1',func=pin_types.PASSIVE),
            Pin(num='3',name='TD1-',func=pin_types.PASSIVE),
            Pin(num='4',name='TCT2',func=pin_types.PASSIVE),
            Pin(num='5',name='TD2+',func=pin_types.PASSIVE),
            Pin(num='6',name='TD2-',func=pin_types.PASSIVE),
            Pin(num='7',name='TCT3',func=pin_types.PASSIVE),
            Pin(num='8',name='TD3+',func=pin_types.PASSIVE),
            Pin(num='9',name='TD3-',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'TR1-SO8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR1-SO8'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTR1-SO8\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR60_FC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR60_FC'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTR60_FC\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR60_IC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR60_IC'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTR60_IC\n\n', 'pins':[
            Pin(num='1',name='1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='2',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TR60_IC2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TR60_IC2'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTR60_IC2\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF1'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF1\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF2'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF2\n\n', 'pins':[
            Pin(num='0',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF3'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF3\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF4', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF4'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF4\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF5'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF5\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF6'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF6\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF7', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF7'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF7\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TRANSF8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TRANSF8'}), 'ref_prefix':'TR', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTRANSF8\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Triad_VPP16-310', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Triad_VPP16-310'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Triad_VPP16-310'], 'footprint':'Transformer_THT:Transformer_Triad_VPP16-310', 'keywords':'power center-tap', 'description':'', 'datasheet':'https://catalog.triadmagnetics.com/Asset/VPP16-310.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTriad_VPP16-310\n\npower center-tap', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE),
            Pin(num='10',name='~',func=pin_types.PASSIVE),
            Pin(num='12',name='~',func=pin_types.PASSIVE),
            Pin(num='3',name='~',func=pin_types.PASSIVE),
            Pin(num='4',name='~',func=pin_types.PASSIVE),
            Pin(num='6',name='~',func=pin_types.PASSIVE),
            Pin(num='7',name='~',func=pin_types.PASSIVE),
            Pin(num='9',name='~',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'Wuerth_750315371', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Wuerth_750315371'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Wuerth_750315371'], 'footprint':'Transformer_SMD:Transformer_Wuerth_750315371', 'keywords':'Power Center Tapped Flyback Transformer AEC-Q200', 'description':'', 'datasheet':'https://www.we-online.com/catalog/datasheet/750315371.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nWuerth_750315371\n\nPower Center Tapped Flyback Transformer AEC-Q200', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Wuerth_750343373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Wuerth_750343373'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Wuerth_750343373'], 'footprint':'Transformer_THT:Transformer_Wuerth_750343373', 'keywords':'PCB Flyback Transformer Dual Secondary', 'description':'', 'datasheet':'https://katalog.we-online.com/ctm/datasheet/750343373.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nWuerth_750343373\n\nPCB Flyback Transformer Dual Secondary', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='~',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Wuerth_760871131', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Wuerth_760871131'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Wuerth_760871131'], 'footprint':'Transformer_THT:Transformer_Wuerth_760871131', 'keywords':'flyback dual secondary single aux', 'description':'', 'datasheet':'https://www.we-online.com/catalog/datasheet/760871131.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nWuerth_760871131\n\nflyback dual secondary single aux', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Wurth_750319177', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Wurth_750319177'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Wurth_WE-AGDT-EP7'], 'footprint':'Transformer_SMD:Transformer_Wurth_WE-AGDT-EP7', 'keywords':'auxiliary gate drive transformer low insulation capacitance', 'description':'', 'datasheet':'https://www.we-online.com/components/products/datasheet/750319177.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nWurth_750319177\n\nauxiliary gate drive transformer low insulation capacitance', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZMCT103C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZMCT103C'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Zeming_ZMCT103C'], 'footprint':'Transformer_THT:Transformer_Zeming_ZMCT103C', 'keywords':'current sense transformer', 'description':'', 'datasheet':'https://5krorwxhmqqirik.leadongcdn.com/ZMCT103C+specification-aidirBqoKomRilSjpimnokp.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nZMCT103C\n\ncurrent sense transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZMPT101K', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZMPT101K'}), 'ref_prefix':'TR', 'fplist':['Transformer_THT:Transformer_Zeming_ZMPT101K'], 'footprint':'Transformer_THT:Transformer_Zeming_ZMPT101K', 'keywords':'', 'description':'', 'datasheet':'https://5krorwxhmqqirik.leadongcdn.com/ZMPT101K+specification-aidikBqoKomRilSkopqmikp.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nZMPT101K\n\n', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'0433BM15A0001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'0433BM15A0001'}), 'ref_prefix':'U', 'fplist':['RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001'], 'footprint':'RF_Converter:Balun_Johanson_0896BM15A0001', 'keywords':'balun rf transformer', 'description':'', 'datasheet':'https://www.johansontechnology.com/datasheets/0433BM15A0001/0433BM15A0001.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n0433BM15A0001\n\nbalun rf transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'0868BM15C0001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'0868BM15C0001'}), 'ref_prefix':'U', 'fplist':['RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001'], 'footprint':'RF_Converter:Balun_Johanson_0896BM15A0001', 'keywords':'balun rf transformer', 'description':'', 'datasheet':'https://www.johansontechnology.com/datasheets/0868BM15C0001/0868BM15C0001.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n0868BM15C0001\n\nbalun rf transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'0915BM15A0001', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'0915BM15A0001'}), 'ref_prefix':'U', 'fplist':['RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001', 'RF_Converter:Balun_Johanson_0896BM15A0001'], 'footprint':'RF_Converter:Balun_Johanson_0896BM15A0001', 'keywords':'balun rf transformer', 'description':'', 'datasheet':'https://www.johansontechnology.com/datasheets/0915BM15A0001/0915BM15A0001.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\n0915BM15A0001\n\nbalun rf transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT16-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT16-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT16-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT16-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT16-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT16-6'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT16-6+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT16-6\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT16-6T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT16-6T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT16-6T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT16-6T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT2-1T-1P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT2-1T-1P'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT2-1T-1P+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT2-1T-1P\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT2-71T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT2-71T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT2-71T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT2-71T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT3-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT3-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT3-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT3-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT3-1T-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT3-1T-75'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT3-1T-75+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT3-1T-75\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-1WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-1WT'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-1WT+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-1WT\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-5WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-5WT'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-5WT+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-5WT\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-6T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-6T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-6T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-6T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT4-6WT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT4-6WT'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT4-6WT+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT4-6WT\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT8-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT8-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD637_H5.23mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT8-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT8-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADT9-1T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADT9-1T'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADT9-1T+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADT9-1T\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTL1-12', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTL1-12'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTL1-12+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTL1-12\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTL1-18-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTL1-18-75'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTL1-18-75+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTL1-18-75\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTL2-18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTL2-18'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD542_H2.84mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTL2-18+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTL2-18\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTT3-2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTT3-2'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTT3-2+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTT3-2\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ADTT4-1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ADTT4-1'}), 'ref_prefix':'TR', 'fplist':['RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm'], 'footprint':'RF_Mini-Circuits:Mini-Circuits_CD636_H4.11mm', 'keywords':'Mini-Circuits RF Transformer', 'description':'', 'datasheet':'https://www.minicircuits.com/pdfs/ADTT4-1+.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nADTT4-1\n\nMini-Circuits RF Transformer', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'P0544NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'P0544NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nP0544NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0173NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0173NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2005NL', 'Transformer_SMD:Pulse_PA2005NL'], 'footprint':'Transformer_SMD:Pulse_PA2005NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0173NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0184NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0184NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2007NL', 'Transformer_SMD:Pulse_PA2007NL'], 'footprint':'Transformer_SMD:Pulse_PA2007NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0184NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0184NL1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0184NL1'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2777NL', 'Transformer_SMD:Pulse_PA2777NL'], 'footprint':'Transformer_SMD:Pulse_PA2777NL', 'keywords':'pulse', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0184NL1\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0185NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0185NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2006NL', 'Transformer_SMD:Pulse_PA2006NL'], 'footprint':'Transformer_SMD:Pulse_PA2006NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0185NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0185NL1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0185NL1'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA3493NL', 'Transformer_SMD:Pulse_PA3493NL'], 'footprint':'Transformer_SMD:Pulse_PA3493NL', 'keywords':'pulse', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0185NL1\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0264NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0264NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2004NL', 'Transformer_SMD:Pulse_PA2004NL'], 'footprint':'Transformer_SMD:Pulse_PA2004NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0264NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0297NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0297NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0297NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA0510NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA0510NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA0510NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2008NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2008NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2008NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PA2009NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PA2009NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL'], 'footprint':'Transformer_SMD:Pulse_PA2002NL-PA2008NL-PA2009NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/P663.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPA2009NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PE-68386NL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PE-68386NL'}), 'ref_prefix':'T', 'fplist':['Transformer_SMD:Pulse_PA2001NL', 'Transformer_SMD:Pulse_PA2001NL'], 'footprint':'Transformer_SMD:Pulse_PA2001NL', 'keywords':'pulse', 'description':'', 'datasheet':'https://productfinder.pulseeng.com/products/datasheets/SPM2007_61.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nPE-68386NL\n\npulse', 'pins':[
            Pin(num='1',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TG110-S050N2xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TG110-S050N2xx'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_Halo_N5_SO-16_7.11x12.7mm', 'Transformer_SMD:Transformer_Ethernet_Halo_N2_SO-16_7.11x12.7mm'], 'footprint':'Transformer_SMD:Transformer_Ethernet_Halo_N5_SO-16_7.11x12.7mm', 'keywords':'single port ethernet transformer', 'description':'', 'datasheet':'https://www.haloelectronics.com/pdf/discrete-ultra-100baset.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nTG110-S050N2xx\n\nsingle port ethernet transformer', 'pins':[
            Pin(num='1',name='TX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='C_RD',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C_TD',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C_TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='RX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C_RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='RD+',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Wuerth_749013011A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Wuerth_749013011A'}), 'ref_prefix':'TR', 'fplist':['Transformer_SMD:Transformer_Ethernet_Bourns_PT61017PEL', 'Transformer_SMD:Transformer_Ethernet_Wuerth_749013011A'], 'footprint':'Transformer_SMD:Transformer_Ethernet_Bourns_PT61017PEL', 'keywords':'single port ethernet transformer poe center tap', 'description':'', 'datasheet':'https://www.we-online.com/katalog/datasheet/749013011A.pdf', 'search_text':'/usr/share/kicad/symbols/Transformer.kicad_sym\nWuerth_749013011A\n\nsingle port ethernet transformer poe center tap', 'pins':[
            Pin(num='1',name='TD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='C_RX',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='TX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C_TX',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='TX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='C_TD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='RD+',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='C_RD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RD-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='RX-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])